package sgc.portal.cd.cd0102.persistence;
import java.util.List;

import org.apache.ibatis.annotations.Mapper;

import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cd.cd0102.dto.CD01020001USearch;
import sgc.portal.cd.cd0102.model.CD01020001U;

@Mapper
public interface CD01020001UMapper {

	//CON_DAY_SITE 조회
	List<EasyHashMap<String, Object>> selectConDaySiteList(CD01020001USearch search);
	
	//CON_DAY_SITE 추가 삭제 수정
	int selectConDaySiteCount(CD01020001U cD01020001U);
	
	int insertConDaySite(CD01020001U cD01020001U);

    int updateConDaySite(CD01020001U cD01020001U);

    int deleteConDaySite(CD01020001U cD01020001U);
    
	//CON_DAY_SITE_COVEND 조회
	List<EasyHashMap<String, Object>> selectConDaySiteCovendList(CD01020001USearch search);
	
	//CON_DAY_SITE_COVEND 추가 삭제 수정
	int selectConDaySiteCovendCount(CD01020001U cD01020001U);
	
	int insertConDaySiteCovend(CD01020001U cD01020001U);

    int updateConDaySiteCovend(CD01020001U cD01020001U);

    int deleteConDaySiteCovend(CD01020001U cD01020001U);
    
    int deleteConDaySiteCovendAll(CD01020001U cD01020001U);
}
